# IMAGINE
A software package searching for specific image information embedded in the files' metadata (e.g. aspect ratio, pixel count, image resolution) and display the results.

The full documentation can be found here: https://imagine-imagesearch.readthedocs.io/en/latest/

[![codecov](https://codecov.io/gh/luisepevestorff/IMAGINE/graph/badge.svg?token=RDP4FLTCQN)](https://codecov.io/gh/luisepevestorff/IMAGINE)
[![CodeCov](https://github.com/luisepevestorff/IMAGINE/actions/workflows/workflow_codecov.yml/badge.svg)](https://github.com/luisepevestorff/IMAGINE/actions/workflows/workflow_codecov.yml)
